# Open Meteo CLI
![Status](https://ci.midefos.com/api/badges/midefos/open-meteo-cli/status.svg)

CLI to extract meteorology data from Open Meteo.

## Usage

### Current Weather

Displays the current weather for your IP address automatically or for specific coordinates.

```
open-meteo-cli current-weather [FLAGS] [OPTIONS]
```

#### Options
- `-l, --latitude <latitude>`: Latitude as a decimal number.
- `-L, --longitude <longitude>`: Longitude as a decimal number.
- `--temperature-unit <temperature-unit>`: Switches between Celsius or Fahrenheit. Default value is Celsius.
- `--speed-unit <speed-unit>`: Switches between km/h, m/s, mp/h or knots. Default value is Kmh.
- `--format <format>`: Switches data format between Normal, Clean or JSON. Default value is Normal.

#### Flags
- `-a, --all`: Displays all the information.
- `-d, --is-day`: Displays if it is day or night.
- `-t, --temperature`: Displays the decimal temperature.
- `-w, --windspeed`: Displays the decimal wind speed.
- `-W, --winddirection`: Displays the wind direction, in degrees.
- `--coords`: Displays the latitude and the longitude.
- `--city`: Displays the city.
- `-c, --clean`: Displays the output separated by commas. Same as '--format clean'.
    - The order of values is as follows: latitude, longitude, city, is_day, temperature, windspeed, winddirection.
- `-j, --json`: Displays the output as JSON. Same as '--format json'

#### Examples

- Standard usage: `open-meteo-cli current-weather -a`

```
      ┌──────────────────────────────────────────────────┐
      │                                                  │
      │      === Current weather for Zaragoza ===        │
      │      Night                                       │
      │      Temperature: 18.8°C                         │
      │      Wind speed: 6.6 km/h                        │
      │      Wind direction: 22°                         │
      │      Latitude: 41.6405, Longitude: -0.8814       │
      │      === Weather data by Open-Meteo.com ===      │
      │                                                  │
      └──────────────────────────────────────────────────┘
```

- Using coordinates: `open-meteo-cli current-weather -l 12.2 -L=-0.38 -t -w`

```
      ┌──────────────────────────────────────────────────┐
      │                                                  │
      │      === Current weather ===                     │
      │      Temperature: 32.6°C                         │
      │      Wind speed: 12.5 km/h                       │
      │      === Weather data by Open-Meteo.com ===      │
      │                                                  │
      └──────────────────────────────────────────────────┘
```

- Clean: `open-meteo-cli current-weather -d -t -w -c`

```
0,18.8,6.6
```

- JSON: `open-meteo-cli current-weather -d -t -w -j`

```
{"is_day":0,"temperature":18.8,"windspeed":6.6}
```

## Attribution

The weather data used in this application is provided by [Open-Meteo.com](https://open-meteo.com/) under the [CC BY 4.0](https://creativecommons.org/licenses/by/4.0/) license. 
We would like to express our gratitude to Open-Meteo.com for their contribution to this project.
